@@ -1,7 +1,7 @@
 package Perinci::Use;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-09-04'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -164,7 +164,7 @@ Perinci::Use - Use a Riap package as if it was a local Perl module
 
 =head1 VERSION
 
-This document describes version 0.05 of Perinci::Use (from Perl distribution Perinci-Use), released on 2015-08-18.
+This document describes version 0.06 of Perinci::Use (from Perl distribution Perinci-Use), released on 2015-09-04.
 
 =head1 SYNOPSIS
 
@@ -185,16 +185,14 @@ Perl's use().
 
 =head2 use_riap_package(%args) -> [status, msg, result, meta]
 
-{en_US Use a Riap package as if it was a local Perl module}.
+Use a Riap package as if it was a local Perl module.
 
-{en_US 
 "Use" a remote code package over Riap protocol as if it was a local Perl module.
 Actually, what is being done is query the remote URL for available functions,
 and for each remote function, create a proxy function. The proxy function will
 then call the remote function.
 
 Currently only functions are imported. Variables and other entities are ignored.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -202,23 +200,19 @@ Arguments ('*' denotes required arguments):
 
 =item * B<include> => I<array[str]>
 
-{en_US Do not load all children, only load specified ones}.
+Do not load all children, only load specified ones.
 
 =item * B<into>* => I<str>
 
-{en_US Perl package name to put proxy functions into}.
+Perl package name to put proxy functions into.
 
-{en_US 
 Example: 'Foo::Bar', 'Example::Module'.
-}
 
 =item * B<url>* => I<str>
 
-{en_US Location of Riap package entity}.
+Location of Riap package entity.
 
-{en_US 
 Example: '/Foo/Bar/' (local Perl module), 'http://example.com/api/Module/'.
-}
 
 =back
 
